==> xoonips-3.45.zip: xoonips-3.45/xoonips/class/xoonipsrequest.class.php <==
<?php
// $Revision: 1.1.4.1.2.2 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

/**
 *
 * @brief Class that has parameters of a requrest
 *
 */
class XooNIpsRequest
{

    /**
     *
     * @brief requested logic name
     */
    var $method = false;

    /**
     *
     * @brief parameters
     */
    var $vars = false;

    /**
     * @brief get requested logic name
     */
    function &getMethod() 
    {
        return $this->method;
    }

    /**
     * @brief get all parameters.
     */
    function &getVars() 
    {
        return $this->vars;
    }
    function setMethod($method) 
    {
        $this->method = $method;
    }
    function setVars(&$params) 
    {
        $this->vars = $params;
    }
}

?>

==> xoonips-3.49.zip: xoonips-3.49/xoonips/class/xoonipsrequest.class.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

/**
 * @brief Class that has parameters of a requrest
 */
class XooNIpsRequest
{
    /**
     * @brief requested logic name
     */
    public $method = false;

    /**
     * @brief parameters
     */
    public $vars = false;

    /**
     * @brief get requested logic name
     */
    public function &getMethod()
    {
        return $this->method;
    }

    /**
     * @brief get all parameters.
     */
    public function &getVars()
    {
        return $this->vars;
    }

    public function setMethod($method)
    {
        $this->method = $method;
    }

    public function setVars(&$params)
    {
        $this->vars = $params;
    }
}
